wallet

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package wallet contains private wallet read parameters and response models.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client provides explicitly authenticated wallet reads.

func NewClient

func NewClient(client *core.Client) Client

NewClient binds the wallet module to a shared client.

func (Client) Info

func (w Client) Info(ctx context.Context, params InfoParams) (Info, error)

type Info

type Info struct {
	MID               int64   `json:"mid"`
	TotalBPCoin       float64 `json:"totalBp"`
	DefaultBPCoin     float64 `json:"defaultBp"`
	IOSBPCoin         float64 `json:"iosBp"`
	CouponBalance     float64 `json:"couponBalance"`
	AvailableBPCoin   float64 `json:"availableBp"`
	UnavailableBPCoin float64 `json:"unavailableBp"`
	UnavailableReason string  `json:"unavailableReason"`
	Tip               string  `json:"tip"`
	ShowClassBalance  int64   `json:"needShowClassBalance"`
}

type InfoParams

type InfoParams struct {
	// contains filtered or unexported fields
}

func InfoParamsAtMilliseconds

func InfoParamsAtMilliseconds(timestampMS int64) (InfoParams, error)

func (InfoParams) RequestBody

func (p InfoParams) RequestBody(csrf string) (any, error)

func (InfoParams) WithPlatformType

func (p InfoParams) WithPlatformType(platformType uint32) (InfoParams, error)

func (InfoParams) WithTraceID

func (p InfoParams) WithTraceID(traceID int64) (InfoParams, error)

func (InfoParams) WithVersion

func (p InfoParams) WithVersion(version string) (InfoParams, error)

Jump to